==> fragment-shader-4.0.1.tgz: package/classes/Renderer.ts <==
import { Layer } from '../types/layers';
import Shader from './Shader';
import { type Uniform } from '../types/uniforms';
import { type ShaderConfig } from '../types/shader';
import { log } from '../util/log';
import { getParentFromConfig } from '../util/dom';

export default class Renderer {
  private layers: Layer[];
  private shader: Shader;
  public config: ShaderConfig;

  constructor(layers: Layer[], config: ShaderConfig) {
    this.config = config;
    this.config.parent = getParentFromConfig(config);
    this.layers = layers;
    this.shader = new Shader({
      ...this.config,
      fragmentShader: this.fragmentShader,
    });

    this.log('self', this);
  }

  get layerDeclarations() {
    const declarations = this.layers.reduce((acc, layer, i) => {
      acc += `vec4 layer_${i} (vec2 uv) {`;
      acc += layer.shader;
      acc += `\n  return vec4(color, 1.);\n`;
      acc += `}\n\n`;
      return acc;
    }, '');

    this.log('layer:declarations', declarations);

    return declarations;
  }

  get fragmentShader() {
    let shader = `
${this.layerDeclarations}

void main () {
  vec2 uv = k_uv(gl_FragCoord);
`;

    this.layers.forEach((layer, i) => {
      const mode = layer.mode || '';
      shader += `  gl_FragColor ${i === 0 ? '' : mode}= layer_${i}(uv);\n`;
    });

    shader += '}';

    return shader;
  }

  set uniform(value: Uniform) {
    this.shader.uniform = value;
  }

  log(label: string, data: unknown) {
    if (this.shader?.config?.debug) log('renderer', label, data);
  }

  tick(now: DOMHighResTimeStamp = window.performance.now()) {
    this.shader.tick(now);
  }
}

==> fragment-shader-4.1.0.tgz: package/classes/Renderer.ts <==
import Shader from './Shader';
import { type UniformTuple, type ShaderConfig, type Layer } from '../types';
import { log } from '../util/log';
import { getParentFromConfig } from '../util/dom';

export default class Renderer {
  private layers: Layer[];
  private shader: Shader;
  public config: ShaderConfig;

  constructor(layers: Layer[], config: ShaderConfig) {
    this.config = config;
    this.config.parent = getParentFromConfig(config);
    this.layers = layers;
    this.shader = new Shader({
      ...this.config,
      fragmentShader: this.fragmentShader,
    });

    this.log('self', this);
  }

  get layerDeclarations() {
    const declarations = this.layers.reduce((acc, layer, i) => {
      acc += `vec4 layer_${i} (vec2 uv) {`;
      acc += layer.shader;
      acc += `\n  return vec4(color, 1.);\n`;
      acc += `}\n\n`;
      return acc;
    }, '');

    this.log('layer:declarations', declarations);

    return declarations;
  }

  get fragmentShader() {
    let shader = `
${this.layerDeclarations}

void main () {
  vec2 uv = k_uv(gl_FragCoord);
`;

    this.layers.forEach((layer, i) => {
      const mode = layer.mode || '';
      shader += `  gl_FragColor ${i === 0 ? '' : mode}= layer_${i}(uv);\n`;
    });

    shader += '}';

    return shader;
  }

  set uniform(value: UniformTuple) {
    this.shader.uniform = value;
  }

  log(label: string, data: unknown) {
    if (this.shader?.config?.debug) log('renderer', label, data);
  }

  tick(now: DOMHighResTimeStamp = window.performance.now()) {
    this.shader.tick(now);
  }
}
